# -*- coding: utf-8 -*-


"""
Provides Dymaxion package information.
"""


__author__ =        "Lars van Vianen"
__copyright__ =     "Copyright 2023, Geoid"
__credits__ =       [
                        "Lars van Vianen",
                    ]
__license__ =       "Creative Commons Attribution-ShareAlike 4.0 International License"
__version__ =       "0.0.0"
__maintainer__ =    "Geoid"
__email__ =         "info@geoid.org"
__status__ =        "Alpha"
